@@ -44,15 +44,15 @@
 
 #include "kpLogCategories.h"
 
-#include <qapplication.h>
-#include <qbitmap.h>
-#include <qcursor.h>
-#include <qevent.h>
-#include <qmenu.h>
-#include <qpainter.h>
-#include <qpixmap.h>
-#include <qpolygon.h>
-#include <qtimer.h>
+#include <QApplication>
+#include <QBitmap>
+#include <QCursor>
+#include <QEvent>
+#include <QMenu>
+#include <QPainter>
+#include <QPixmap>
+#include <QPolygon>
+#include <QTimer>
 
 
 kpToolSelectionCreateCommand::kpToolSelectionCreateCommand (const QString &name,
@@ -105,8 +105,7 @@ void kpToolSelectionCreateCommand::execute ()
     {
     #if DEBUG_KP_TOOL_SELECTION
         qCDebug(kpLogCommands) << "\tusing fromSelection";
-        qCDebug(kpLogCommands) << "\t\thave sel=" << doc->selection ()
-                   << endl;
+        qCDebug(kpLogCommands) << "\t\thave sel=" << doc->selection () << endl;
     #endif
         kpAbstractImageSelection *imageSel =
             dynamic_cast <kpAbstractImageSelection *> (m_fromSelection);
@@ -114,16 +113,19 @@ void kpToolSelectionCreateCommand::execute ()
             dynamic_cast <kpTextSelection *> (m_fromSelection);
         if (imageSel)
         {
-            if (imageSel->transparency () != environ ()->imageSelectionTransparency ())
+            if (imageSel->transparency () != environ ()->imageSelectionTransparency ()) {
                 environ ()->setImageSelectionTransparency (imageSel->transparency ());
+            }
         }
         else if (textSel)
         {
-            if (textSel->textStyle () != environ ()->textStyle ())
+            if (textSel->textStyle () != environ ()->textStyle ()) {
                 environ ()->setTextStyle (textSel->textStyle ());
+            }
         }
-        else
+        else {
             Q_ASSERT (!"Unknown selection type");
+        }
 
         viewManager ()->setTextCursorPosition (m_textRow, m_textCol);
         doc->setSelection (*m_fromSelection);
@@ -141,8 +143,9 @@ void kpToolSelectionCreateCommand::unexecute ()
     if (!doc->selection ())
     {
         // Was just a border that got deselected?
-        if (m_fromSelection && !m_fromSelection->hasContent ())
+        if (m_fromSelection && !m_fromSelection->hasContent ()) {
             return;
+        }
 
         Q_ASSERT (!"kpToolSelectionCreateCommand::unexecute() without sel region");
         return;
