@@ -119,14 +119,15 @@ kpDocumentMetaInfoDialog::kpDocumentMetaInfoDialog (
 
 
     setWindowTitle (i18nc ("@title:window", "Document Properties"));
-    QDialogButtonBox * buttons = new QDialogButtonBox (QDialogButtonBox::Ok |
+    auto * buttons = new QDialogButtonBox (QDialogButtonBox::Ok |
                                                        QDialogButtonBox::Cancel, this);
-    connect (buttons, SIGNAL (accepted()), this, SLOT (accept()));
-    connect (buttons, SIGNAL (rejected()), this, SLOT (reject()));
 
-    QWidget *baseWidget = new QWidget (this);
+    connect (buttons, &QDialogButtonBox::accepted, this, &kpDocumentMetaInfoDialog::accept);
+    connect (buttons, &QDialogButtonBox::rejected, this, &kpDocumentMetaInfoDialog::reject);
 
-    QVBoxLayout *dialogLayout = new QVBoxLayout (this);
+    auto *baseWidget = new QWidget (this);
+
+    auto *dialogLayout = new QVBoxLayout (this);
     dialogLayout->addWidget (baseWidget);
     dialogLayout->addWidget (buttons);
 
@@ -137,7 +138,7 @@ kpDocumentMetaInfoDialog::kpDocumentMetaInfoDialog (
 
     Q_ASSERT (::DpiInputMin < ::DpiInputMax);
 
-    QGroupBox *dpiGroupBox = new QGroupBox(i18n("Dots &Per Inch (DPI)"), baseWidget);
+    auto *dpiGroupBox = new QGroupBox(i18n("Dots &Per Inch (DPI)"), baseWidget);
 
     d->horizDpiInput = new QDoubleSpinBox(dpiGroupBox);
     d->horizDpiInput->setRange(::DpiInputMin, ::DpiInputMax);
@@ -146,7 +147,7 @@ kpDocumentMetaInfoDialog::kpDocumentMetaInfoDialog (
     d->horizDpiInput->setDecimals(::DpiPrecision);
     d->horizDpiInput->setSpecialValueText(i18n("Unspecified"));
 
-    QLabel *dpiXLabel = new QLabel (
+    auto *dpiXLabel = new QLabel (
         i18nc ("Horizontal DPI 'x' Vertical DPI", " x "), dpiGroupBox);
     dpiXLabel->setAlignment (Qt::AlignCenter);
 
@@ -158,7 +159,7 @@ kpDocumentMetaInfoDialog::kpDocumentMetaInfoDialog (
     d->vertDpiInput->setSpecialValueText(i18n("Unspecified"));
 
 
-    QGridLayout *dpiLay = new QGridLayout(dpiGroupBox);
+    auto *dpiLay = new QGridLayout(dpiGroupBox);
 
     dpiLay->addWidget(new QLabel(i18n("Horizontal:")), 0, 0, Qt::AlignHCenter);
     dpiLay->addWidget(d->horizDpiInput, 1, 0);
@@ -201,7 +202,7 @@ kpDocumentMetaInfoDialog::kpDocumentMetaInfoDialog (
     // Offset Group Box
     //
 
-    QGroupBox *offsetGroupBox = new QGroupBox(i18n ("O&ffset"), baseWidget);
+    auto *offsetGroupBox = new QGroupBox(i18n ("O&ffset"), baseWidget);
 
     d->horizOffsetInput = new QSpinBox;
     d->horizOffsetInput->setRange(kpDocumentMetaInfo::MinOffset, kpDocumentMetaInfo::MaxOffset);
@@ -209,7 +210,7 @@ kpDocumentMetaInfoDialog::kpDocumentMetaInfoDialog (
     d->vertOffsetInput = new QSpinBox;
     d->vertOffsetInput->setRange(kpDocumentMetaInfo::MinOffset, kpDocumentMetaInfo::MaxOffset);
 
-    QGridLayout *offsetLay = new QGridLayout(offsetGroupBox);
+    auto *offsetLay = new QGridLayout(offsetGroupBox);
 
     offsetLay->addWidget(new QLabel(i18n("Horizontal:")), 0, 0, Qt::AlignHCenter);
     offsetLay->addWidget(d->horizOffsetInput, 1, 0);
@@ -237,40 +238,40 @@ kpDocumentMetaInfoDialog::kpDocumentMetaInfoDialog (
     //
 
 
-    QGroupBox *fieldsGroupBox = new QGroupBox (i18n ("&Text Fields"),
+    auto *fieldsGroupBox = new QGroupBox (i18n ("&Text Fields"),
         baseWidget);
 
     d->fieldsTableWidget = new QTableWidget (fieldsGroupBox);
     d->fieldsTableWidget->setEditTriggers(QAbstractItemView::AllEditTriggers);
 
-    connect (d->fieldsTableWidget, SIGNAL (currentCellChanged(int,int,int,int)),
-             SLOT (slotFieldsCurrentCellChanged(int,int,int,int)));
+    connect (d->fieldsTableWidget, &QTableWidget::currentCellChanged,
+             this, &kpDocumentMetaInfoDialog::slotFieldsCurrentCellChanged);
 
-    connect (d->fieldsTableWidget, SIGNAL (itemChanged(QTableWidgetItem*)),
-             SLOT (slotFieldsItemChanged(QTableWidgetItem*)));
+    connect (d->fieldsTableWidget, &QTableWidget::itemChanged,
+             this, &kpDocumentMetaInfoDialog::slotFieldsItemChanged);
 
     d->fieldsAddRowButton = new QPushButton (i18n ("&Add Row"),
         fieldsGroupBox);
-    connect (d->fieldsAddRowButton, SIGNAL (clicked()),
-             SLOT (slotFieldsAddRowButtonClicked()));
+    connect (d->fieldsAddRowButton, &QPushButton::clicked,
+             this, &kpDocumentMetaInfoDialog::slotFieldsAddRowButtonClicked);
 
     d->fieldsDeleteRowButton = new QPushButton (i18n ("&Delete Row"),
         fieldsGroupBox);
-    connect (d->fieldsDeleteRowButton, SIGNAL (clicked()),
-             SLOT (slotFieldsDeleteRowButtonClicked()));
+    connect (d->fieldsDeleteRowButton, &QPushButton::clicked,
+             this, &kpDocumentMetaInfoDialog::slotFieldsDeleteRowButtonClicked);
 
     d->fieldsResetButton = new QPushButton (i18n ("&Reset"),
         fieldsGroupBox);
-    connect (d->fieldsResetButton, SIGNAL (clicked()),
-             SLOT (setUIToOriginalMetaInfo()));
+    connect (d->fieldsResetButton, &QPushButton::clicked,
+             this, &kpDocumentMetaInfoDialog::setUIToOriginalMetaInfo);
 
-    QHBoxLayout *fieldsButtonsLayout = new QHBoxLayout ();
+    auto *fieldsButtonsLayout = new QHBoxLayout ();
     fieldsButtonsLayout->addWidget (d->fieldsAddRowButton);
     fieldsButtonsLayout->addWidget (d->fieldsDeleteRowButton);
     fieldsButtonsLayout->addStretch ();
     fieldsButtonsLayout->addWidget (d->fieldsResetButton);
 
-    QVBoxLayout *fieldsLayout = new QVBoxLayout (fieldsGroupBox);
+    auto *fieldsLayout = new QVBoxLayout (fieldsGroupBox);
 
     fieldsLayout->addWidget (d->fieldsTableWidget);
     fieldsLayout->addLayout (fieldsButtonsLayout);
@@ -295,10 +296,8 @@ kpDocumentMetaInfoDialog::kpDocumentMetaInfoDialog (
     //
     // Global Layout
     //
-
-
-    QGridLayout *baseLayout = new QGridLayout (baseWidget);
-    baseLayout->setMargin (0);
+    auto *baseLayout = new QGridLayout (baseWidget);
+    baseLayout->setContentsMargins(0, 0, 0, 0);
 
     // Col 0
     baseLayout->addWidget (dpiGroupBox, 0, 0);
@@ -317,15 +316,17 @@ kpDocumentMetaInfoDialog::kpDocumentMetaInfoDialog (
     setUIToOriginalMetaInfo ();
 
 
-    if (::LastWidth > 0 && ::LastHeight > 0)
+    if (::LastWidth > 0 && ::LastHeight > 0) {
         resize (::LastWidth, ::LastHeight);
+    }
 }
 
 //---------------------------------------------------------------------
 
 kpDocumentMetaInfoDialog::~kpDocumentMetaInfoDialog ()
 {
-    ::LastWidth = width (), ::LastHeight = height ();
+    ::LastWidth = width ();
+    ::LastHeight = height ();
 
     delete d;
 }
@@ -372,7 +373,7 @@ void kpDocumentMetaInfoDialog::setUIToOriginalMetaInfo ()
         d->fieldsTableWidget->setHorizontalHeaderLabels (fieldsHeader);
 
         int row = 0;
-        foreach (const QString &key, d->originalMetaInfoPtr->textKeys ())
+        for (const auto &key : d->originalMetaInfoPtr->textKeys ())
         {
             d->fieldsTableWidget->setItem (row, 0/*1st col*/,
                 new QTableWidgetItem (key));
@@ -423,15 +424,19 @@ kpDocumentMetaInfo kpDocumentMetaInfoDialog::metaInfo (
     kpDocumentMetaInfo ret;
 
 
-    if (d->horizDpiInput->value () < ::DpiLegalMin)
+    if (d->horizDpiInput->value () < ::DpiLegalMin) {
         ret.setDotsPerMeterX (0/*unspecified*/);
-    else
+    }
+    else {
         ret.setDotsPerMeterX (qRound (d->horizDpiInput->value () * KP_INCHES_PER_METER));
+    }
 
-    if (d->vertDpiInput->value () < ::DpiLegalMin)
+    if (d->vertDpiInput->value () < ::DpiLegalMin) {
         ret.setDotsPerMeterY (0/*unspecified*/);
-    else
+    }
+    else {
         ret.setDotsPerMeterY (qRound (d->vertDpiInput->value () * KP_INCHES_PER_METER));
+    }
 
 
     ret.setOffset (QPoint (d->horizOffsetInput->value (),
@@ -453,21 +458,21 @@ kpDocumentMetaInfo kpDocumentMetaInfoDialog::metaInfo (
                 continue;
             }
             // Value without a key?
-            else
+
+
+            if (errorMessage)
             {
-                if (errorMessage)
-                {
-                    *errorMessage =
+                *errorMessage =
                         ki18n ("The text value \"%1\" on line %2 requires a key.")
-                            .subs (value).subs (r + 1/*count from 1*/).toString ();
+                        .subs (value).subs (r + 1/*count from 1*/).toString ();
 
-                    // Print only 1 error message per method invocation.
-                    errorMessage = nullptr;
-                }
-
-                // Ignore.
-                continue;
+                // Print only 1 error message per method invocation.
+                errorMessage = nullptr;
             }
+
+            // Ignore.
+            continue;
+
         }
 
         // Duplicate key?
@@ -478,8 +483,9 @@ kpDocumentMetaInfo kpDocumentMetaInfoDialog::metaInfo (
                 int q;
                 for (q = 0; q < r; q++)
                 {
-                    if (d->fieldsTableWidget->item (q, 0)->text () == key)
+                    if (d->fieldsTableWidget->item (q, 0)->text () == key) {
                         break;
+                    }
                 }
                 Q_ASSERT (q != r);
 
@@ -512,8 +518,9 @@ kpDocumentMetaInfo kpDocumentMetaInfoDialog::metaInfo (
 void kpDocumentMetaInfoDialog::fieldsUpdateVerticalHeader ()
 {
     QStringList vertLabels;
-    for (int r = 1; r <= d->fieldsTableWidget->rowCount (); r++)
+    for (int r = 1; r <= d->fieldsTableWidget->rowCount (); r++) {
         vertLabels << QString::number (r);
+    }
 
     d->fieldsTableWidget->setVerticalHeaderLabels (vertLabels);
 }
@@ -561,7 +568,7 @@ void kpDocumentMetaInfoDialog::fieldsDeleteRow (int r)
 #if DEBUG_KP_DOCUMENT_META_INFO_DIALOG
     qCDebug(kpLogDialogs) << "kpDocumentMetaInfoDialog::fieldsDeleteRow("
               << "row=" << r << ")"
-              << " currentRow=" << d->fieldsTableWidget->currentRow () << endl;
+              << " currentRow=" << d->fieldsTableWidget->currentRow ();
 #endif
 
     Q_ASSERT (isFieldsRowDeleteable (r));
@@ -651,8 +658,7 @@ void kpDocumentMetaInfoDialog::slotFieldsItemChanged (QTableWidgetItem *it)
 {
 #if DEBUG_KP_DOCUMENT_META_INFO_DIALOG
     qCDebug(kpLogDialogs) << "kpDocumentMetaInfoDialog::slotFieldsItemChanged("
-              << "item=" << it << ") rows=" << d->fieldsTableWidget->rowCount ()
-              << endl;
+              << "item=" << it << ") rows=" << d->fieldsTableWidget->rowCount ();
 #endif
 
     const int r = d->fieldsTableWidget->row (it);
@@ -686,23 +692,6 @@ void kpDocumentMetaInfoDialog::slotFieldsItemChanged (QTableWidgetItem *it)
             fieldsAppendEmptyRow ();
         }
     }
-// Deletes a row if it is emptied of text.
-#if 0
-    // At any normal row?
-    else
-    {   // Emptied all the text?
-        if (key.isEmpty () && value.isEmpty ())
-        {
-            // This crashes when the user tabs away after the text is deleted.
-            // We could use a single shot but that's asking for trouble depending
-            // on what happens between us and the single shot.
-            //
-            // In any case, disabling this makes us more consistent with
-            // "Add Row" which allows us to add empty rows.
-            //fieldsDeleteRow (r);
-        }
-    }
-#endif
 }
 
 //---------------------------------------------------------------------
@@ -711,8 +700,7 @@ void kpDocumentMetaInfoDialog::slotFieldsItemChanged (QTableWidgetItem *it)
 void kpDocumentMetaInfoDialog::slotFieldsAddRowButtonClicked ()
 {
 #if DEBUG_KP_DOCUMENT_META_INFO_DIALOG
-    qCDebug(kpLogDialogs) << "kpDocumentMetaInfoDialog::slotFieldsAddRowButtonClicked()"
-              << endl;
+    qCDebug(kpLogDialogs) << "kpDocumentMetaInfoDialog::slotFieldsAddRowButtonClicked()";
 #endif
 
     const int r = d->fieldsTableWidget->currentRow ();
@@ -734,8 +722,7 @@ void kpDocumentMetaInfoDialog::slotFieldsAddRowButtonClicked ()
 void kpDocumentMetaInfoDialog::slotFieldsDeleteRowButtonClicked ()
 {
 #if DEBUG_KP_DOCUMENT_META_INFO_DIALOG
-    qCDebug(kpLogDialogs) << "kpDocumentMetaInfoDialog::slotFieldsDeleteRowButtonClicked()"
-              << endl;
+    qCDebug(kpLogDialogs) << "kpDocumentMetaInfoDialog::slotFieldsDeleteRowButtonClicked()";
 #endif
 
     const int r = d->fieldsTableWidget->currentRow ();
