@@ -30,11 +30,11 @@
 
 #include "kpDocumentSaveOptionsPreviewDialog.h"
 
-#include <qevent.h>
-#include <qgridlayout.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qpixmap.h>
+#include <QEvent>
+#include <QGridLayout>
+#include <QLabel>
+#include <QLayout>
+#include <QPixmap>
 
 #include <kconfig.h>
 #include "kpLogCategories.h"
@@ -60,11 +60,11 @@ kpDocumentSaveOptionsPreviewDialog::kpDocumentSaveOptionsPreviewDialog (
 {
     setWindowTitle (i18nc ("@title:window", "Save Preview"));
 
-    QWidget *baseWidget = this;//new QWidget (this);
+    auto *baseWidget = this;//new QWidget (this);
     //setMainWidget (baseWidget);
 
 
-    QGridLayout *lay = new QGridLayout ( baseWidget );
+    auto *lay = new QGridLayout ( baseWidget );
 
     m_filePixmapLabel = new kpResizeSignallingLabel (baseWidget);
     m_fileSizeLabel = new QLabel (baseWidget);
@@ -80,8 +80,8 @@ kpDocumentSaveOptionsPreviewDialog::kpDocumentSaveOptionsPreviewDialog (
     lay->setRowStretch (0, 1);
 
 
-    connect (m_filePixmapLabel, SIGNAL (resized()),
-             this, SLOT (updatePixmapPreview()));
+    connect (m_filePixmapLabel, &kpResizeSignallingLabel::resized,
+             this, &kpDocumentSaveOptionsPreviewDialog::updatePixmapPreview);
 }
 
 kpDocumentSaveOptionsPreviewDialog::~kpDocumentSaveOptionsPreviewDialog ()
@@ -93,11 +93,10 @@ kpDocumentSaveOptionsPreviewDialog::~kpDocumentSaveOptionsPreviewDialog ()
 // public
 QSize kpDocumentSaveOptionsPreviewDialog::preferredMinimumSize () const
 {
-    const int contentsWidth = 180;
-    const int totalMarginsWidth = fontMetrics ().height ();
+    const auto contentsWidth = 180;
+    const auto totalMarginsWidth = fontMetrics ().height ();
 
-    return QSize (contentsWidth + totalMarginsWidth,
-                  contentsWidth * 3 / 4 + totalMarginsWidth);
+    return  {contentsWidth + totalMarginsWidth, contentsWidth * 3 / 4 + totalMarginsWidth};
 }
 
 
@@ -117,15 +116,14 @@ void kpDocumentSaveOptionsPreviewDialog::setFilePixmapAndSize (const QImage &pix
     //  -- i.e. INT_MAX / 100 -- times the pixmap size)
     const int percent = pixmapSize ?
                             qMax (1,
-                                  (int) ((kpCommandSize::SizeType) fileSize * 100 / pixmapSize)) :
+                                  static_cast<int> (static_cast<kpCommandSize::SizeType> (fileSize * 100 / pixmapSize))) :
                             0;
 #if DEBUG_KP_DOCUMENT_SAVE_OPTIONS_WIDGET
     qCDebug(kpLogDialogs) << "kpDocumentSaveOptionsPreviewDialog::setFilePixmapAndSize()"
                << " pixmapSize=" << pixmapSize
                << " fileSize=" << fileSize
                << " raw fileSize/pixmapSize%="
-               << (pixmapSize ? (kpCommandSize::SizeType) fileSize * 100 / pixmapSize : 0)
-               << endl;
+               << (pixmapSize ? (kpCommandSize::SizeType) fileSize * 100 / pixmapSize : 0);
 #endif
 
     m_fileSizeLabel->setText (i18np ("1 byte (approx. %2%)", "%1 bytes (approx. %2%)",
@@ -138,8 +136,7 @@ void kpDocumentSaveOptionsPreviewDialog::updatePixmapPreview ()
 #if DEBUG_KP_DOCUMENT_SAVE_OPTIONS_WIDGET
     qCDebug(kpLogDialogs) << "kpDocumentSaveOptionsPreviewDialog::updatePreviewPixmap()"
                << " filePixmapLabel.size=" << m_filePixmapLabel->size ()
-               << " filePixmap.size=" << m_filePixmap->size ()
-               << endl;
+               << " filePixmap.size=" << m_filePixmap->size ();
 #endif
 
     if (m_filePixmap)
@@ -155,11 +152,9 @@ void kpDocumentSaveOptionsPreviewDialog::updatePixmapPreview ()
     #if DEBUG_KP_DOCUMENT_SAVE_OPTIONS_WIDGET
         qCDebug(kpLogDialogs) << "\tmaxNewWidth=" << maxNewWidth
                    << " maxNewHeight=" << maxNewHeight
-                   << " keepsAspect=" << keepsAspect
-                   << endl;
+                   << " keepsAspect=" << keepsAspect;
     #endif
 
-
         const int newWidth = kpTransformPreviewDialog::scaleDimension (
             m_filePixmap->width (),
             keepsAspect,
@@ -172,11 +167,9 @@ void kpDocumentSaveOptionsPreviewDialog::updatePixmapPreview ()
             maxNewHeight);
     #if DEBUG_KP_DOCUMENT_SAVE_OPTIONS_WIDGET
         qCDebug(kpLogDialogs) << "\tnewWidth=" << newWidth
-                   << " newHeight=" << newHeight
-                   << endl;
+                   << " newHeight=" << newHeight;
     #endif
 
-
         QImage transformedPixmap =
             kpPixmapFX::scale (*m_filePixmap,
                                newWidth, newHeight);
