@@ -31,7 +31,7 @@
 
 #include "generic/widgets/kpResizeSignallingLabel.h"
 
-#include <qevent.h>
+#include <QEvent>
 
 #include "kpLogCategories.h"
 
@@ -47,9 +47,7 @@ kpResizeSignallingLabel::kpResizeSignallingLabel (QWidget *parent )
 {
 }
 
-kpResizeSignallingLabel::~kpResizeSignallingLabel ()
-{
-}
+kpResizeSignallingLabel::~kpResizeSignallingLabel () = default;
 
 
 // protected virtual [base QLabel]
@@ -57,7 +55,7 @@ void kpResizeSignallingLabel::resizeEvent (QResizeEvent *e)
 {
 #if DEBUG_KP_RESIZE_SIGNALLING_LABEL
     qCDebug(kpLogMisc) << "kpResizeSignallingLabel::resizeEvent() newSize=" << e->size ()
-               << " oldSize=" << e->oldSize () << endl;
+               << " oldSize=" << e->oldSize ();
 #endif
     QLabel::resizeEvent (e);
 
