@@ -31,9 +31,9 @@
 
 #include "kpEffectBalance.h"
 
-#include <math.h>
+#include <cmath>
 
-#include <qimage.h>
+#include <QImage>
 
 #include "kpLogCategories.h"
 
@@ -47,12 +47,15 @@
 
 static inline int between0And255 (int val)
 {
-    if (val < 0)
+    if (val < 0) {
         return 0;
-    else if (val > 255)
+    }
+
+    if (val > 255) {
         return 255;
-    else
-        return val;
+    }
+
+    return val;
 }
 
 
@@ -68,7 +71,7 @@ static inline int contrast (int base, int strength)
 
 static inline int gamma (int base, int strength)
 {
-    return between0And255 (qRound (255.0 * pow (base / 255.0, 1.0 / pow (10., strength / 50.0))));
+    return between0And255 (qRound (255.0 * std::pow (base / 255.0, 1.0 / std::pow (10., strength / 50.0))));
 }
 
 
@@ -90,13 +93,15 @@ static inline QRgb brightnessContrastGammaForRGB (QRgb rgb,
     int green = qGreen (rgb);
     int blue = qBlue (rgb);
 
-
-    if (channels & kpEffectBalance::Red)
+    if (channels & kpEffectBalance::Red) {
         red = brightnessContrastGamma (red, brightness, contrast, gamma);
-    if (channels & kpEffectBalance::Green)
+    }
+    if (channels & kpEffectBalance::Green) {
         green = brightnessContrastGamma (green, brightness, contrast, gamma);
-    if (channels & kpEffectBalance::Blue)
+    }
+    if (channels & kpEffectBalance::Blue) {
         blue = brightnessContrastGamma (blue, brightness, contrast, gamma);
+    }
 
 
     return qRgba (red, green, blue, qAlpha (rgb));
@@ -114,7 +119,7 @@ kpImage kpEffectBalance::applyEffect (const kpImage &image,
                << ",brightness=" << brightness
                << ",contrast=" << contrast
                << ",gamma=" << gamma
-               << ")" << endl;
+               << ")";
     QTime timer; timer.start ();
 #endif
 
@@ -130,22 +135,28 @@ kpImage kpEffectBalance::applyEffect (const kpImage &image,
 
     for (int i = 0; i < 256; i++)
     {
-        quint8 applied = (quint8) brightnessContrastGamma (i, brightness, contrast, gamma);
+        auto applied = static_cast<quint8> (brightnessContrastGamma (i, brightness, contrast, gamma));
 
-        if (channels & kpEffectBalance::Red)
+        if (channels & kpEffectBalance::Red) {
             transformRed [i] = applied;
-        else
-            transformRed [i] = i;
+        }
+        else {
+            transformRed [i] = static_cast<quint8> (i);
+        }
 
-        if (channels & kpEffectBalance::Green)
+        if (channels & kpEffectBalance::Green) {
             transformGreen [i] = applied;
-        else
-            transformGreen [i] = i;
+        }
+        else {
+            transformGreen [i] = static_cast<quint8> (i);
+        }
 
-        if (channels & kpEffectBalance::Blue)
+        if (channels & kpEffectBalance::Blue) {
             transformBlue [i] = applied;
-        else
-            transformBlue [i] = i;
+        }
+        else {
+            transformBlue [i] = static_cast<quint8> (i);
+        }
     }
 
 #if DEBUG_KP_EFFECT_BALANCE
@@ -161,23 +172,16 @@ kpImage kpEffectBalance::applyEffect (const kpImage &image,
             {
                 const QRgb rgb = qimage.pixel (x, y);
 
-                const quint8 red = (quint8) qRed (rgb);
-                const quint8 green = (quint8) qGreen (rgb);
-                const quint8 blue = (quint8) qBlue (rgb);
-                const quint8 alpha = (quint8) qAlpha (rgb);
+                const auto red = static_cast<quint8> (qRed (rgb));
+                const auto green = static_cast<quint8> (qGreen (rgb));
+                const auto blue = static_cast<quint8> (qBlue (rgb));
+                const auto alpha = static_cast<quint8> (qAlpha (rgb));
 
                 qimage.setPixel (x, y,
                     qRgba (transformRed [red],
                            transformGreen [green],
                            transformBlue [blue],
                            alpha));
-
-            #if 0
-                qimage.setPixel (x, y,
-                    brightnessContrastGammaForRGB (qimage.pixel (x, y),
-                        channels,
-                        brightness, contrast, gamma));
-            #endif
             }
         }
     }
@@ -187,23 +191,16 @@ kpImage kpEffectBalance::applyEffect (const kpImage &image,
         {
             const QRgb rgb = qimage.color (i);
 
-            const quint8 red = (quint8) qRed (rgb);
-            const quint8 green = (quint8) qGreen (rgb);
-            const quint8 blue = (quint8) qBlue (rgb);
-            const quint8 alpha = (quint8) qAlpha (rgb);
+            const auto red = static_cast<quint8> (qRed (rgb));
+            const auto green = static_cast<quint8> (qGreen (rgb));
+            const auto blue = static_cast<quint8> (qBlue (rgb));
+            const auto alpha = static_cast<quint8> (qAlpha (rgb));
 
             qimage.setColor (i,
                 qRgba (transformRed [red],
                        transformGreen [green],
                        transformBlue [blue],
                        alpha));
-
-        #if 0
-            qimage.setColor (i,
-                brightnessContrastGammaForRGB (qimage.color (i),
-                    channels,
-                    brightness, contrast, gamma));
-        #endif
         }
 
     }
