@@ -37,7 +37,7 @@
 #include <QList>
 #include <QPainter>
 
-#include <kdebug.h>
+#include "kpLogCategories.h"
 
 #include "kpColor.h"
 #include "kpImage.h"
@@ -78,10 +78,10 @@ struct kpFloodFillPrivate
     // Copy of whatever was passed to the constructor.
     //
 
-    kpImage *imagePtr;
-    int x, y;
+    kpImage *imagePtr{};
+    int x{}, y{};
     kpColor color;
-    int processedColorSimilarity;
+    int processedColorSimilarity{};
 
 
     //
@@ -100,7 +100,7 @@ struct kpFloodFillPrivate
 
     QRect boundingRect;
 
-    bool prepared;
+    bool prepared{};
 };
 
 //---------------------------------------------------------------------
@@ -110,8 +110,10 @@ kpFloodFill::kpFloodFill (kpImage *image, int x, int y,
     : d (new kpFloodFillPrivate ())
 {
     d->imagePtr = image;
-    d->x = x, d->y = y;
-    d->color = color, d->processedColorSimilarity = processedColorSimilarity;
+    d->x = x;
+    d->y = y;
+    d->color = color;
+    d->processedColorSimilarity = processedColorSimilarity;
 
     d->prepared = false;
 }
@@ -145,7 +147,7 @@ int kpFloodFill::processedColorSimilarity () const
 kpCommandSize::SizeType kpFloodFill::size () const
 {
     kpCommandSize::SizeType fillLinesCacheSize = 0;
-    foreach (const QLinkedList <kpFillLine> &linesList, d->fillLinesCache)
+    for (const auto &linesList : d->fillLinesCache)
     {
         fillLinesCacheSize += ::FillLinesListSize (linesList);
     }
@@ -160,11 +162,12 @@ kpCommandSize::SizeType kpFloodFill::size () const
 // public
 void kpFloodFill::prepareColorToChange ()
 {
-    if (d->colorToChange.isValid ())
+    if (d->colorToChange.isValid ()) {
         return;
+    }
 
 #if DEBUG_KP_FLOOD_FILL && 1
-    kDebug () << "kpFloodFill::prepareColorToChange()";
+    qCDebug(kpLogImagelib) << "kpFloodFill::prepareColorToChange()";
 #endif
 
     d->colorToChange = kpPixmapFX::getColorAtPixel (*d->imagePtr, QPoint (d->x, d->y));
@@ -187,17 +190,19 @@ kpColor kpFloodFill::colorToChange ()
 // private
 kpColor kpFloodFill::pixelColor (int x, int y, bool *beenHere) const
 {
-    if (beenHere)
+    if (beenHere) {
         *beenHere = false;
+    }
 
-    Q_ASSERT (y >= 0 && y < (int) d->fillLinesCache.count ());
+    Q_ASSERT (y >= 0 && y < static_cast<int> (d->fillLinesCache.count ()));
 
-    foreach (const kpFillLine &line, d->fillLinesCache [y])
+    for (const auto &line : d->fillLinesCache [y])
     {
         if (x >= line.m_x1 && x <= line.m_x2)
         {
-            if (beenHere)
+            if (beenHere) {
                 *beenHere = true;
+            }
             return d->color;
         }
     }
@@ -223,13 +228,16 @@ int kpFloodFill::findMinX (int y, int x) const
 {
     for (;;)
     {
-        if (x < 0)
+        if (x < 0) {
             return 0;
+        }
 
-        if (shouldGoTo (x, y))
+        if (shouldGoTo (x, y)) {
             x--;
-        else
+        }
+        else {
             return x + 1;
+        }
     }
 }
 
@@ -240,13 +248,16 @@ int kpFloodFill::findMaxX (int y, int x) const
 {
     for (;;)
     {
-        if (x > d->imagePtr->width () - 1)
+        if (x > d->imagePtr->width () - 1) {
             return d->imagePtr->width () - 1;
+        }
 
-        if (shouldGoTo (x, y))
+        if (shouldGoTo (x, y)) {
             x++;
-        else
+        }
+        else {
             return x - 1;
+        }
     }
 }
 
@@ -256,7 +267,7 @@ int kpFloodFill::findMaxX (int y, int x) const
 void kpFloodFill::addLine (int y, int x1, int x2)
 {
 #if DEBUG_KP_FLOOD_FILL && 0
-    kDebug () << "kpFillCommand::fillAddLine ("
+    qCDebug(kpLogImagelib) << "kpFillCommand::fillAddLine ("
               << y << "," << x1 << "," << x2 << ")" << endl;
 #endif
 
@@ -272,8 +283,9 @@ void kpFloodFill::addLine (int y, int x1, int x2)
 void kpFloodFill::findAndAddLines (const kpFillLine &fillLine, int dy)
 {
     // out of bounds?
-    if (fillLine.m_y + dy < 0 || fillLine.m_y + dy >= d->imagePtr->height ())
+    if (fillLine.m_y + dy < 0 || fillLine.m_y + dy >= d->imagePtr->height ()) {
         return;
+    }
 
     for (int xnow = fillLine.m_x1; xnow <= fillLine.m_x2; xnow++)
     {
@@ -298,11 +310,12 @@ void kpFloodFill::findAndAddLines (const kpFillLine &fillLine, int dy)
 // public
 void kpFloodFill::prepare ()
 {
-    if (d->prepared)
+    if (d->prepared) {
         return;
+    }
 
 #if DEBUG_KP_FLOOD_FILL && 1
-    kDebug () << "kpFloodFill::prepare()";
+    qCDebug(kpLogImagelib) << "kpFloodFill::prepare()";
 #endif
 
     prepareColorToChange ();
@@ -311,7 +324,7 @@ void kpFloodFill::prepare ()
 
 
 #if DEBUG_KP_FLOOD_FILL && 1
-    kDebug () << "\tperforming NOP check";
+    qCDebug(kpLogImagelib) << "\tperforming NOP check";
 #endif
 
     // get the color we need to replace
@@ -324,15 +337,16 @@ void kpFloodFill::prepare ()
     }
 
 #if DEBUG_KP_FLOOD_FILL && 1
-    kDebug () << "\tcreating fillLinesCache";
+    qCDebug(kpLogImagelib) << "\tcreating fillLinesCache";
 #endif
 
     // ready cache
-    for (int i = 0; i < d->imagePtr->height (); i++)
+    for (int i = 0; i < d->imagePtr->height (); i++) {
          d->fillLinesCache.append (QLinkedList <kpFillLine> ());
+    }
 
 #if DEBUG_KP_FLOOD_FILL && 1
-    kDebug () << "\tcreating fill lines";
+    qCDebug(kpLogImagelib) << "\tcreating fill lines";
 #endif
 
     // draw initial line
@@ -343,7 +357,7 @@ void kpFloodFill::prepare ()
          ++it)
     {
     #if DEBUG_KP_FLOOD_FILL && 0
-        kDebug () << "Expanding from y=" << (*it).m_y
+        qCDebug(kpLogImagelib) << "Expanding from y=" << (*it).m_y
                    << " x1=" << (*it).m_x1
                    << " x2=" << (*it).m_x2
                    << endl;
@@ -363,7 +377,7 @@ void kpFloodFill::prepare ()
     }
 
 #if DEBUG_KP_FLOOD_FILL && 1
-    kDebug () << "\tfinalising memory usage";
+    qCDebug(kpLogImagelib) << "\tfinalising memory usage";
 #endif
 
     // finalize memory usage
@@ -394,17 +408,20 @@ void kpFloodFill::fill()
 
     // by definition, flood fill with a fully transparent color erases the pixels
     // and sets them to be fully transparent
-    if ( d->color.isTransparent() )
+    if ( d->color.isTransparent() ) {
       painter.setCompositionMode(QPainter::CompositionMode_Clear);
+    }
 
     painter.setPen(d->color.toQColor());
 
-    foreach (const kpFillLine &l, d->fillLines)
+    for (const auto &l : d->fillLines)
     {
-      if ( l.m_x1 == l.m_x2 )
+      if ( l.m_x1 == l.m_x2 ) {
         painter.drawPoint(l.m_x1, l.m_y);
-      else
+      }
+      else {
         painter.drawLine(l.m_x1, l.m_y, l.m_x2, l.m_y);
+      }
     }
 
     QApplication::restoreOverrideCursor();
