@@ -83,11 +83,6 @@ QList <QPoint> kpPainter::interpolatePoints (const QPoint &startPoint,
 #define SHOULD_DRAW()  (probabilityTimes1000 == 1000/*avoid ::RandomNumberFrom0to999() call*/ ||  \
                         ::RandomNumberFrom0to999 () < probabilityTimes1000)
 
-#if 0
-    qCDebug(kpLogImagelib) << "prob=" << probability
-               << " *1000=" << probabilityTimes1000;
-#endif
-
 
     // Derived from the zSprite2 Graphics Engine.
     // "MODIFIED" comment shows deviation from zSprite2 and Bresenham's line
@@ -116,8 +111,9 @@ QList <QPoint> kpPainter::interpolatePoints (const QPoint &startPoint,
     int x = 0;
     int y = 0;
 
-    if (SHOULD_DRAW ())
+    if (SHOULD_DRAW ()) {
         ret.append (QPoint (plotx, ploty));
+    }
 
 
     for (int i = 0; i <= inc; i++)
@@ -135,10 +131,12 @@ QList <QPoint> kpPainter::interpolatePoints (const QPoint &startPoint,
             plot++;
             x -= inc;
 
-            if (dx < 0)
+            if (dx < 0) {
                 plotx--;
-            else
+            }
+            else {
                 plotx++;
+            }
         }
 
         if (y > inc)
@@ -146,10 +144,12 @@ QList <QPoint> kpPainter::interpolatePoints (const QPoint &startPoint,
             plot++;
             y -= inc;
 
-            if (dy < 0)
+            if (dy < 0) {
                 ploty--;
-            else
+            }
+            else {
                 ploty++;
+            }
         }
 
         if (plot)
@@ -161,12 +161,14 @@ QList <QPoint> kpPainter::interpolatePoints (const QPoint &startPoint,
                 // is more than 1 point, of course).  This is in contrast to the
                 // ordinary line algorithm which can create diagonal adjacencies.
 
-                if (SHOULD_DRAW ())
+                if (SHOULD_DRAW ()) {
                     ret.append (QPoint (plotx, oldploty));
+                }
             }
 
-            if (SHOULD_DRAW ())
+            if (SHOULD_DRAW ()) {
                 ret.append (QPoint (plotx, ploty));
+            }
         }
     }
 
@@ -177,53 +179,6 @@ QList <QPoint> kpPainter::interpolatePoints (const QPoint &startPoint,
 
 //---------------------------------------------------------------------
 
-// public static
-void kpPainter::drawLine (kpImage *image,
-        int x1, int y1, int x2, int y2,
-        const kpColor &color, int penWidth)
-{
-    kpPixmapFX::drawLine (image, x1, y1, x2, y2, color, penWidth);
-}
-
-//---------------------------------------------------------------------
-
-// public static
-void kpPainter::drawPolyline (kpImage *image,
-        const QPolygon &points,
-        const kpColor &color, int penWidth)
-{
-    kpPixmapFX::drawPolyline (image, points, color, penWidth);
-}
-
-//---------------------------------------------------------------------
-
-// public static
-void kpPainter::drawPolygon (kpImage *image,
-        const QPolygon &points,
-        const kpColor &fcolor, int penWidth,
-        const kpColor &bcolor,
-        bool isFinal)
-{
-    kpPixmapFX::drawPolygon (image, points, fcolor, penWidth, bcolor, isFinal);
-}
-
-//---------------------------------------------------------------------
-
-
-// public static
-void kpPainter::drawCurve (kpImage *image,
-    const QPoint &startPoint,
-    const QPoint &controlPointP, const QPoint &controlPointQ,
-    const QPoint &endPoint,
-    const kpColor &color, int penWidth)
-{
-    kpPixmapFX::drawCurve (image,
-        startPoint, controlPointP, controlPointQ, endPoint, color, penWidth);
-}
-
-//---------------------------------------------------------------------
-
-
 // public static
 void kpPainter::fillRect (kpImage *image,
         int x, int y, int width, int height,
@@ -235,40 +190,6 @@ void kpPainter::fillRect (kpImage *image,
 //---------------------------------------------------------------------
 
 
-// public static
-void kpPainter::drawRect (kpImage *image,
-        int x, int y, int width, int height,
-        const kpColor &fcolor, int penWidth,
-        const kpColor &bcolor)
-{
-    kpPixmapFX::drawRect (image, x, y, width, height, fcolor, penWidth, bcolor);
-}
-
-//---------------------------------------------------------------------
-
-// public static
-void kpPainter::drawRoundedRect (kpImage *image,
-        int x, int y, int width, int height,
-        const kpColor &fcolor, int penWidth,
-        const kpColor &bcolor)
-{
-    kpPixmapFX::drawRoundedRect (image, x, y, width, height, fcolor, penWidth, bcolor);
-}
-
-//---------------------------------------------------------------------
-
-// public static
-void kpPainter::drawEllipse (kpImage *image,
-        int x, int y, int width, int height,
-        const kpColor &fcolor, int penWidth,
-        const kpColor &bcolor)
-{
-    kpPixmapFX::drawEllipse (image, x, y, width, height, fcolor, penWidth, bcolor);
-}
-
-//---------------------------------------------------------------------
-
-
 // <rgbPainter> are operating on the original image
 // (the original image is not passed to this function).
 //
@@ -336,21 +257,24 @@ static bool ReadableImageWashRect (QPainter *rgbPainter,
             #if DEBUG_KP_PAINTER && 0
                 fprintf (stderr, "similar\n");
             #endif
-                if (startDrawX < 0)
+                if (startDrawX < 0) {
                     startDrawX = x;
+                }
             }
             else
             {
             #if DEBUG_KP_PAINTER && 0
                 fprintf (stderr, "different\n");
             #endif
-                if (startDrawX >= 0)
+                if (startDrawX >= 0) {
                     FLUSH_LINE ();
+                }
             }
         }
 
-        if (startDrawX >= 0)
+        if (startDrawX >= 0) {
             FLUSH_LINE ();
+        }
     }
 
 #undef FLUSH_LINE
@@ -364,9 +288,9 @@ struct WashPack
 {
     QPoint startPoint, endPoint;
     kpColor color;
-    int penWidth, penHeight;
+    int penWidth{}, penHeight{};
     kpColor colorToReplace;
-    int processedColorSimilarity;
+    int processedColorSimilarity{};
 
     QRect readableImageRect;
     QImage readableImage;
@@ -413,8 +337,9 @@ void WashHelperSetup (QPainter *rgbPainter, const WashPack *pack)
 {
     // Set the drawing colors for the painters.
 
-    if (rgbPainter)
+    if (rgbPainter) {
         rgbPainter->setPen (pack->color.toQColor());
+    }
 }
 
 //---------------------------------------------------------------------
@@ -428,8 +353,7 @@ static QRect WashLineHelper (QPainter *rgbPainter, void *data)
     int convAndWashTime;
 #endif
 
-    WashPack *pack = static_cast <WashPack *> (data);
-
+    auto *pack = static_cast <WashPack *> (data);
 
     // Setup painters.
     ::WashHelperSetup (rgbPainter, pack);
@@ -497,6 +421,7 @@ QRect kpPainter::washLine (kpImage *image,
 
 static QRect WashRectHelper (QPainter *rgbPainter, void *data)
 {
+    auto *pack = static_cast <WashPack *> (data);
 #if DEBUG_KP_PAINTER && 0
     qCDebug(kpLogImagelib) << "Washing pixmap (w=" << rect.width ()
                 << ",h=" << rect.height () << ")" << endl;
@@ -504,9 +429,6 @@ static QRect WashRectHelper (QPainter *rgbPainter, void *data)
     int convAndWashTime;
 #endif
 
-    WashPack *pack = static_cast <WashPack *> (data);
-
-
     // Setup painters.
     ::WashHelperSetup (rgbPainter, pack);
 
@@ -577,7 +499,7 @@ void kpPainter::sprayPoints (kpImage *image,
 
     painter.setPen(color.toQColor());
 
-    foreach (const QPoint &p, points)
+    for (const auto &p : points)
     {
         for (int i = 0; i < 10; i++)
         {
@@ -587,8 +509,9 @@ void kpPainter::sprayPoints (kpImage *image,
             // Make it look circular.
             // TODO: Can be done better by doing a random vector angle & length
             //       but would sin and cos be too slow?
-            if ((dx * dx) + (dy * dy) > (radius * radius))
+            if ((dx * dx) + (dy * dy) > (radius * radius)) {
                 continue;
+            }
 
             const QPoint p2 (p.x () + dx, p.y () + dy);
 
