@@ -133,8 +133,9 @@ int kpFreeFormImageSelection::serialID () const
 // public virtual [base kpAbstractImageSelection]
 bool kpFreeFormImageSelection::readFromStream (QDataStream &stream)
 {
-    if (!kpAbstractImageSelection::readFromStream (stream))
+    if (!kpAbstractImageSelection::readFromStream (stream)) {
         return false;
+    }
 
     stream >> d->orgPoints;
     recalculateCardinallyAdjacentPoints ();
@@ -176,17 +177,17 @@ QPolygon kpFreeFormImageSelection::originalPoints () const
 static QPolygon RecalculateCardinallyAdjacentPoints (const QPolygon &points)
 {
 #if DEBUG_KP_SELECTION
-    qCDebug(kpLogLayers) << "kpFreeFormImageSelection.cpp:RecalculateCardinallyAdjacentPoints()"
-              << endl;
+    qCDebug(kpLogLayers) << "kpFreeFormImageSelection.cpp:RecalculateCardinallyAdjacentPoints()";
     qCDebug(kpLogLayers) << "\tpoints=" << points;
 #endif
 
     // Filter out duplicates.
     QPolygon noDups;
-    foreach (const QPoint &p, points)
+    for (const auto &p : points)
     {
-        if (!noDups.isEmpty () && p == noDups.last ())
+        if (!noDups.isEmpty () && p == noDups.last ()) {
             continue;
+        }
 
         noDups.append (p);
     }
@@ -196,7 +197,7 @@ static QPolygon RecalculateCardinallyAdjacentPoints (const QPolygon &points)
 
     // Interpolate to ensure cardinal adjacency.
     QPolygon cardPoints;
-    foreach (const QPoint &p, noDups)
+    for (const auto &p : noDups)
     {
         if (!cardPoints.isEmpty () &&
             !kpPainter::pointsAreCardinallyAdjacent (p, cardPoints.last ()))
@@ -219,8 +220,9 @@ static QPolygon RecalculateCardinallyAdjacentPoints (const QPolygon &points)
                 cardPoints.append (interpPoints [i]);
             }
         }
-        else
+        else {
             cardPoints.append (p);
+        }
     }
 #if DEBUG_KP_SELECTION
     qCDebug(kpLogLayers) << "\tcardinally adjacent=" << cardPoints;
@@ -236,8 +238,9 @@ void kpFreeFormImageSelection::recalculateCardinallyAdjacentPoints ()
 
 
     QPolygon pointsLoop = d->cardPointsCache;
-    if (!pointsLoop.isEmpty ())
+    if (!pointsLoop.isEmpty ()) {
         pointsLoop.append (pointsLoop.first ());
+    }
 
     // OPT: We know this method only needs to act on the last 2 points of
     //      "pointLoop", since the previous points are definitely cardinally
@@ -301,8 +304,9 @@ QRegion kpFreeFormImageSelection::shapeRegion () const
 // public virtual [kpAbstractSelection]
 bool kpFreeFormImageSelection::contains (const QPoint &point) const
 {
-    if (!boundingRect ().contains (point))
+    if (!boundingRect ().contains (point)) {
         return false;
+    }
 
     // We can't use the baseImage() (when non-null) and get the transparency of
     // the pixel at <point>, instead of this region test, as the pixel may be
@@ -333,7 +337,7 @@ static void FlipPoints (QPolygon *points,
 {
     points->translate (-oldRect.x (), -oldRect.y ());
 
-    const QMatrix matrix (horiz ? -1 : +1,  // m11
+    const QTransform matrix (horiz ? -1 : +1,  // m11
                           0,  // m12
                           0,  // m21
                           vert  ? -1 : +1,  // m22
@@ -377,12 +381,14 @@ void kpFreeFormImageSelection::flip (bool horiz, bool vert)
 void kpFreeFormImageSelection::paintBorder (QImage *destPixmap, const QRect &docRect,
         bool selectionFinished) const
 {
-    if (selectionFinished)
+    if (selectionFinished) {
         paintPolygonalBorder (cardinallyAdjacentPointsLoop (),
             destPixmap, docRect, selectionFinished);
-    else
+    }
+    else {
         paintPolygonalBorder (cardinallyAdjacentPoints (),
             destPixmap, docRect, selectionFinished);
+    }
 }
 
 
