@@ -265,7 +265,7 @@ static void SaveToFile (kpColorCollectionPrivate *d, QIODevice *device)
    QTextStream str (device);
 
    QString description = d->desc.trimmed();
-   description = '#'+description.split( '\n', QString::KeepEmptyParts).join(QStringLiteral("\n#"));
+   description = '#'+description.split( '\n', QString::KeepEmptyParts).join(QLatin1String("\n#"));
 
    str << "KDE RGB Palette\n";
    str << description << "\n";
