@@ -43,7 +43,7 @@
 #include "views/kpView.h"
 #include "views/manager/kpViewManager.h"
 
-#include <qlist.h>
+#include <QList>
 
 #include <KLocalizedString>
 
@@ -51,8 +51,8 @@
 bool kpToolText::CursorIsOnWordChar (const QList <QString> &textLines,
     int cursorRow, int cursorCol)
 {
-    return (cursorRow >= 0 && cursorRow < (int) textLines.size () &&
-            cursorCol >= 0 && cursorCol < (int) textLines [cursorRow].length () &&
+    return (cursorRow >= 0 && cursorRow < textLines.size () &&
+            cursorCol >= 0 && cursorCol < textLines [cursorRow].length () &&
             !textLines [cursorRow][cursorCol].isSpace ());
 }
 
@@ -68,11 +68,12 @@ bool kpToolText::CursorIsAtStart (const QList <QString> &,
 bool kpToolText::CursorIsAtEnd (const QList <QString> &textLines,
     int cursorRow, int cursorCol)
 {
-    if (textLines.isEmpty ())
+    if (textLines.isEmpty ()) {
         return (cursorRow == 0 && cursorCol == 0);
+    }
         
-    return (cursorRow == (int) textLines.size () - 1 &&
-            cursorCol == (int) textLines [cursorRow].length ());
+    return (cursorRow == textLines.size () - 1 &&
+            cursorCol == textLines [cursorRow].length ());
 }
 
 
@@ -80,8 +81,9 @@ bool kpToolText::CursorIsAtEnd (const QList <QString> &textLines,
 void kpToolText::MoveCursorLeft (const QList <QString> &textLines,
     int *cursorRow, int *cursorCol)
 {
-    if (textLines.isEmpty ())
+    if (textLines.isEmpty ()) {
         return;
+    }
         
     (*cursorCol)--;
 
@@ -93,8 +95,9 @@ void kpToolText::MoveCursorLeft (const QList <QString> &textLines,
             *cursorRow = 0;
             *cursorCol = 0;
         }
-        else
+        else {
             *cursorCol = textLines [*cursorRow].length ();
+        }
     }
 }
 
@@ -102,21 +105,23 @@ void kpToolText::MoveCursorLeft (const QList <QString> &textLines,
 void kpToolText::MoveCursorRight (const QList <QString> &textLines,
     int *cursorRow, int *cursorCol)
 {
-    if (textLines.isEmpty ())
+    if (textLines.isEmpty ()) {
         return;
+    }
         
     (*cursorCol)++;
 
-    if (*cursorCol > (int) textLines [*cursorRow].length ())
+    if (*cursorCol > textLines [*cursorRow].length ())
     {
         (*cursorRow)++;
-        if (*cursorRow > (int) textLines.size () - 1)
+        if (*cursorRow > textLines.size () - 1)
         {
             *cursorRow = textLines.size () - 1;
             *cursorCol = textLines [*cursorRow].length ();
         }
-        else
+        else {
             *cursorCol = 0;
+        }
     }
 }
 
@@ -127,8 +132,9 @@ void kpToolText::MoveCursorRight (const QList <QString> &textLines,
 int kpToolText::MoveCursorToWordStart (const QList <QString> &textLines,
     int *cursorRow, int *cursorCol)
 {
-    if (textLines.isEmpty ())
+    if (textLines.isEmpty ()) {
         return 0;
+    }
 
     int numMoves = 0;
 
@@ -142,8 +148,9 @@ int kpToolText::MoveCursorToWordStart (const QList <QString> &textLines,
 
     // (these comments will exclude the row=0,col=0 boundary case)
 
-    if (IS_ON_ANCHOR ())
+    if (IS_ON_ANCHOR ()) {
         MOVE_CURSOR_LEFT ();
+    }
 
     // --- now we're not on an anchor point (start of word) ---
 
@@ -173,8 +180,9 @@ int kpToolText::MoveCursorToWordStart (const QList <QString> &textLines,
 int kpToolText::MoveCursorToNextWordStart (const QList <QString> &textLines,
     int *cursorRow, int *cursorCol)
 {
-    if (textLines.isEmpty ())
+    if (textLines.isEmpty ()) {
         return 0;
+    }
         
     int numMoves = 0;
 
