@@ -34,9 +34,9 @@
 #include "kpToolTextPrivate.h"
 #include "commands/tools/selection/text/kpToolTextInsertCommand.h"
 
-#include <qevent.h>
+#include <QEvent>
 
-#include <kdebug.h>
+#include "kpLogCategories.h"
 
 #include "document/kpDocument.h"
 #include "layers/selections/text/kpTextSelection.h"
@@ -48,11 +48,10 @@
 void kpToolText::inputMethodEvent (QInputMethodEvent *e)
 {
 #if DEBUG_KP_TOOL_TEXT && 1
-    kDebug () << "kpToolText::inputMethodEvent() preeditString='" << e->preeditString ()
+    qCDebug(kpLogTools) << "kpToolText::inputMethodEvent() preeditString='" << e->preeditString ()
                << "commitString = " << e->commitString ()
                << " replacementStart=" << e->replacementStart ()
-               << " replacementLength=" << e->replacementLength ()
-               << endl;
+               << " replacementLength=" << e->replacementLength ();
 #endif
     kpTextSelection *textSel = document ()->textSelection ();
     if (hasBegunDraw() || !textSel)
@@ -85,8 +84,9 @@ void kpToolText::inputMethodEvent (QInputMethodEvent *e)
     if (!commitString.isEmpty ())
     {
         // commit string
-        if (!d->insertCommand)
+        if (!d->insertCommand) {
             addNewInsertCommand (&d->insertCommand);
+        }
 
         d->insertCommand->addText (commitString);
     }
