@@ -61,8 +61,9 @@ QRect kpView::paintEventGetDocRect (const QRect &viewRect) const
 
     // From the "we aren't sure whether to round up or round down" department:
 
-    if (zoomLevelX () < 100 || zoomLevelY () < 100)
+    if (zoomLevelX () < 100 || zoomLevelY () < 100) {
         docRect = transformViewToDoc (viewRect);
+    }
     else
     {
         // think of a grid - you need to fully cover the zoomed-in pixels
@@ -115,12 +116,14 @@ void kpView::drawTransparentBackground (QPainter *painter,
     // TODO: % is unpredictable with negatives.
 
     int starty = viewRect.y ();
-    if ((starty - patternOrigin.y ()) % cellSize)
+    if ((starty - patternOrigin.y ()) % cellSize) {
         starty -= ((starty - patternOrigin.y ()) % cellSize);
+    }
 
     int startx = viewRect.x ();
-    if ((startx - patternOrigin.x ()) % cellSize)
+    if ((startx - patternOrigin.x ()) % cellSize) {
         startx -= ((startx - patternOrigin.x ()) % cellSize);
+    }
 
 #if DEBUG_KP_VIEW_RENDERER && 1
     qCDebug(kpLogViews) << "\tstartXY=" << QPoint (startx, starty);
@@ -141,13 +144,16 @@ void kpView::drawTransparentBackground (QPainter *painter,
 
             if (parity)
             {
-                if (!isPreview)
+                if (!isPreview) {
                     col = QColor (213, 213, 213);
-                else
+                }
+                else {
                     col = QColor (224, 224, 224);
+                }
             }
-            else
+            else {
                 col = Qt::white;
+            }
 
             painter->fillRect (x, y, cellSize, cellSize, col);
         }
@@ -164,12 +170,13 @@ void kpView::paintEventDrawCheckerBoard (QPainter *painter, const QRect &viewRec
 #if DEBUG_KP_VIEW_RENDERER && 1
     qCDebug(kpLogViews) << "kpView(" << objectName ()
                << ")::paintEventDrawCheckerBoard(viewRect=" << viewRect
-               << ") origin=" << origin () << endl;
+               << ") origin=" << origin ();
 #endif
 
     kpDocument *doc = document ();
-    if (!doc)
+    if (!doc) {
         return;
+    }
 
     QPoint patternOrigin = origin ();
 
@@ -242,8 +249,7 @@ void kpView::paintEventDrawSelection (QImage *destPixmap, const QRect &docRect)
     kpViewManager *vm = viewManager ();
 #if DEBUG_KP_VIEW_RENDERER && 1 || 0
     qCDebug(kpLogViews) << "\tsel border visible="
-               << vm->selectionBorderVisible ()
-               << endl;
+               << vm->selectionBorderVisible ();
 #endif
     if (vm->selectionBorderVisible ())
     {
@@ -261,7 +267,7 @@ void kpView::paintEventDrawSelection (QImage *destPixmap, const QRect &docRect)
     //
     //       However, too much selection repaint code assumes that it
     //       only paints inside its kpAbstractSelection::boundingRect().
-    kpTextSelection *textSel = dynamic_cast <kpTextSelection *> (sel);
+    auto *textSel = dynamic_cast <kpTextSelection *> (sel);
     if (textSel &&
         vm->textCursorEnabled () &&
         (vm->textCursorBlinkState () ||
@@ -289,7 +295,7 @@ void kpView::paintEventDrawSelectionResizeHandles (const QRect &clipRect)
 {
 #if DEBUG_KP_VIEW_RENDERER && 1
     qCDebug(kpLogViews) << "kpView::paintEventDrawSelectionResizeHandles("
-               << clipRect << ")" << endl;
+               << clipRect << ")";
 #endif
 
     if (!selectionLargeEnoughToHaveResizeHandles ())
@@ -332,8 +338,9 @@ void kpView::paintEventDrawSelectionResizeHandles (const QRect &clipRect)
     painter.setPen(Qt::black);
     painter.setBrush(Qt::cyan);
 
-    foreach (const QRect &r, selResizeHandlesRegion.rects())
+    for (const auto &r : selResizeHandlesRegion.rects()) {
       painter.drawRect(r);
+    }
 }
 
 //---------------------------------------------------------------------
@@ -342,8 +349,9 @@ void kpView::paintEventDrawSelectionResizeHandles (const QRect &clipRect)
 void kpView::paintEventDrawTempImage (QImage *destPixmap, const QRect &docRect)
 {
     kpViewManager *vm = viewManager ();
-    if (!vm)
+    if (!vm) {
         return;
+    }
 
     const kpTempImage *tpi = vm->tempImage ();
 #if DEBUG_KP_VIEW_RENDERER && 1
@@ -354,8 +362,9 @@ void kpView::paintEventDrawTempImage (QImage *destPixmap, const QRect &docRect)
                << endl;
 #endif
 
-    if (!tpi || !tpi->isVisible (vm))
+    if (!tpi || !tpi->isVisible (vm)) {
         return;
+    }
 
     tpi->paint (destPixmap, docRect);
 }
@@ -372,19 +381,23 @@ void kpView::paintEventDrawGridLines (QPainter *painter, const QRect &viewRect)
 
   // horizontal lines
   int starty = viewRect.top();
-  if (starty % vzoomMultiple)
+  if (starty % vzoomMultiple) {
     starty = (starty + vzoomMultiple) / vzoomMultiple * vzoomMultiple;
+  }
 
-  for (int y = starty; y <= viewRect.bottom(); y += vzoomMultiple)
+  for (int y = starty; y <= viewRect.bottom(); y += vzoomMultiple) {
     painter->drawLine(viewRect.left(), y, viewRect.right(), y);
+  }
 
   // vertical lines
   int startx = viewRect.left();
-  if (startx % hzoomMultiple)
+  if (startx % hzoomMultiple) {
     startx = (startx + hzoomMultiple) / hzoomMultiple * hzoomMultiple;
+  }
 
-  for (int x = startx; x <= viewRect.right(); x += hzoomMultiple)
+  for (int x = startx; x <= viewRect.right(); x += hzoomMultiple) {
     painter->drawLine(x, viewRect.top (), x, viewRect.bottom());
+  }
 }
 
 //---------------------------------------------------------------------
@@ -432,8 +445,9 @@ void kpView::paintEventDrawDoc_Unclipped (const QRect &viewRect)
     Q_ASSERT (vm);
     Q_ASSERT (doc);
 
-    if (viewRect.isEmpty ())
+    if (viewRect.isEmpty ()) {
         return;
+    }
 
     QRect docRect = paintEventGetDocRect (viewRect);
 
@@ -454,7 +468,7 @@ void kpView::paintEventDrawDoc_Unclipped (const QRect &viewRect)
 
     #if DEBUG_KP_VIEW_RENDERER && 1
         qCDebug(kpLogViews) << "\tdocPixmap.hasAlphaChannel()="
-                  << docPixmap.hasAlphaChannel () << endl;
+                  << docPixmap.hasAlphaChannel ();
     #endif
 
         tempImageWillBeRendered =
@@ -549,8 +563,9 @@ void kpView::paintEvent (QPaintEvent *e)
                << endl;
 #endif
 
-    if (!vm)
+    if (!vm) {
         return;
+    }
 
     if (vm->queueUpdates ())
     {
@@ -562,13 +577,14 @@ void kpView::paintEvent (QPaintEvent *e)
     }
 
     kpDocument *doc = document ();
-    if (!doc)
+    if (!doc) {
         return;
+    }
 
 
     // It seems that e->region() is already clipped by Qt to the visible
     // part of the view (which could be quite small inside a scrollview).
-    QRegion viewRegion = e->region ();
+    const auto& viewRegion = e->region ();
     QVector <QRect> rects = viewRegion.rects ();
 #if DEBUG_KP_VIEW_RENDERER
     qCDebug(kpLogViews) << "\t#rects = " << rects.count ();
@@ -586,7 +602,7 @@ void kpView::paintEvent (QPaintEvent *e)
     // parts of nearby grid lines (which were drawn in a previous iteration)
     // with document pixels.  Those grid line parts are probably not going to
     // be redrawn, so will appear to be missing.
-    foreach (const QRect &r, rects)
+    for (const auto &r : rects)
     {
         paintEventDrawDoc_Unclipped (r);
     }
@@ -598,7 +614,7 @@ void kpView::paintEvent (QPaintEvent *e)
     if ( isGridShown() )
     {
       QPainter painter(this);
-      foreach (const QRect &r, rects)
+      for (const auto &r : rects)
         paintEventDrawGridLines(&painter, r);
     }
 
