@@ -32,9 +32,9 @@
 #include "views/manager/kpViewManager.h"
 #include "kpViewManagerPrivate.h"
 
-#include <qapplication.h>
-#include <qlist.h>
-#include <qtimer.h>
+#include <QApplication>
+#include <QList>
+#include <QTimer>
 
 #include "kpLogCategories.h"
 
@@ -123,8 +123,9 @@ void kpViewManager::unregisterView (kpView *view)
     Q_ASSERT (view);
     Q_ASSERT (d->views.contains (view));
 
-    if (view == d->viewUnderCursor)
+    if (view == d->viewUnderCursor) {
         d->viewUnderCursor = nullptr;
+    }
 
     view->unsetCursor ();
     d->views.removeAll (view);
@@ -148,18 +149,18 @@ kpView *kpViewManager::viewUnderCursor (bool usingQt) const
         Q_ASSERT (!d->viewUnderCursor || d->views.contains (d->viewUnderCursor));
         return d->viewUnderCursor;
     }
-    else
-    {
-        for (QLinkedList <kpView *>::const_iterator it = d->views.begin ();
-             it != d->views.end ();
-             ++it)
-        {
-            if ((*it)->underMouse ())
-                return (*it);
-        }
 
-        return nullptr;
+
+    for (QLinkedList <kpView *>::const_iterator it = d->views.begin ();
+         it != d->views.end ();
+         ++it)
+    {
+        if ((*it)->underMouse ()) {
+            return (*it);
+        }
     }
+
+    return nullptr;
 }
 
 //---------------------------------------------------------------------
@@ -170,16 +171,17 @@ void kpViewManager::setViewUnderCursor (kpView *view)
 #if DEBUG_KP_VIEW_MANAGER && 1
     qCDebug(kpLogViews) << "kpViewManager::setViewUnderCursor ("
                << (view ? view->objectName () : "(none)") << ")"
-               << "  old=" << (d->viewUnderCursor ? d->viewUnderCursor->objectName () : "(none)")
-               << endl;
+               << "  old=" << (d->viewUnderCursor ? d->viewUnderCursor->objectName () : "(none)");
 #endif
-    if (view == d->viewUnderCursor)
+    if (view == d->viewUnderCursor) {
         return;
+    }
 
     d->viewUnderCursor = view;
 
-    if (d->viewUnderCursor)
+    if (d->viewUnderCursor) {
         d->viewUnderCursor->setAttribute (Qt::WA_InputMethodEnabled, d->inputMethodEnabled);
+    }
 
     if (!d->viewUnderCursor)
     {
@@ -213,8 +215,9 @@ bool kpViewManager::hasAViewWithFocus () const
          it != d->views.end ();
          ++it)
     {
-        if ((*it)->isActiveWindow ())
+        if ((*it)->isActiveWindow ()) {
             return true;
+        }
     }
 
     return false;
@@ -268,7 +271,7 @@ void kpViewManager::setTempImage (const kpTempImage &tempImage)
                << tempImage.isBrush ()
                << ",topLeft=" << tempImage.topLeft ()
                << ",image.rect=" << tempImage.image ().rect ()
-               << ")" << endl;
+               << ")";
 #endif
 
     QRect oldRect;
@@ -284,8 +287,9 @@ void kpViewManager::setTempImage (const kpTempImage &tempImage)
 
     setQueueUpdates ();
     {
-        if (oldRect.isValid ())
+        if (oldRect.isValid ()) {
             updateViews (oldRect);
+        }
         updateViews (d->tempImage->rect ());
     }
     restoreQueueUpdates ();
@@ -296,8 +300,9 @@ void kpViewManager::setTempImage (const kpTempImage &tempImage)
 // public
 void kpViewManager::invalidateTempImage ()
 {
-    if (!d->tempImage)
+    if (!d->tempImage) {
         return;
+    }
 
     QRect oldRect = d->tempImage->rect ();
 
@@ -320,13 +325,15 @@ bool kpViewManager::selectionBorderVisible () const
 // public
 void kpViewManager::setSelectionBorderVisible (bool yes)
 {
-    if (d->selectionBorderVisible == yes)
+    if (d->selectionBorderVisible == yes) {
         return;
+    }
 
     d->selectionBorderVisible = yes;
 
-    if (document ()->selection ())
+    if (document ()->selection ()) {
         updateViews (document ()->selection ()->boundingRect ());
+    }
 }
 
 //---------------------------------------------------------------------
@@ -342,13 +349,15 @@ bool kpViewManager::selectionBorderFinished () const
 // public
 void kpViewManager::setSelectionBorderFinished (bool yes)
 {
-    if (d->selectionBorderFinished == yes)
+    if (d->selectionBorderFinished == yes) {
         return;
+    }
 
     d->selectionBorderFinished = yes;
 
-    if (document ()->selection ())
+    if (document ()->selection ()) {
         updateViews (document ()->selection ()->boundingRect ());
+    }
 }
 
 //---------------------------------------------------------------------
@@ -356,8 +365,9 @@ void kpViewManager::setSelectionBorderFinished (bool yes)
 void kpViewManager::setInputMethodEnabled (bool inputMethodEnabled)
 {
     d->inputMethodEnabled = inputMethodEnabled;
-    if (d->viewUnderCursor)
+    if (d->viewUnderCursor) {
         d->viewUnderCursor->setAttribute (Qt::WA_InputMethodEnabled, inputMethodEnabled);
+    }
 }
 
 //---------------------------------------------------------------------
