@@ -28,13 +28,13 @@
 
 #include "kpEffectHSVWidget.h"
 
-#include <qgridlayout.h>
-#include <qlabel.h>
+#include <QGridLayout>
+#include <QLabel>
 
 #include "kpLogCategories.h"
 #include <KLocalizedString>
-#include <knuminput.h> // kdelibs4support
 
+#include "kpNumInput.h"
 #include "imagelib/effects/kpEffectHSV.h"
 #include "commands/imagelib/effects/kpEffectHSVCommand.h"
 
@@ -42,21 +42,21 @@
 kpEffectHSVWidget::kpEffectHSVWidget (bool actOnSelection, QWidget *parent)
     : kpEffectWidgetBase (actOnSelection, parent)
 {
-    QGridLayout *lay = new QGridLayout (this);
-    lay->setMargin (0);
+    auto *lay = new QGridLayout (this);
+    lay->setContentsMargins(0, 0, 0, 0);
 
-    QLabel *hueLabel = new QLabel (i18n ("&Hue:"), this);
-    QLabel *saturationLabel = new QLabel (i18n ("&Saturation:"), this);
-    QLabel *valueLabel = new QLabel (i18nc ("The V of HSV", "&Value:"), this);
+    auto *hueLabel = new QLabel (i18n ("&Hue:"), this);
+    auto *saturationLabel = new QLabel (i18n ("&Saturation:"), this);
+    auto *valueLabel = new QLabel (i18nc ("The V of HSV", "&Value:"), this);
 
-    m_hueInput = new KDoubleNumInput (this);
-    m_hueInput->setRange (-180, 180, 15/*step*/, true/*slider*/);
+    m_hueInput = new kpDoubleNumInput (this);
+    m_hueInput->setRange (-180, 180, 15/*step*/);
 
-    m_saturationInput = new KDoubleNumInput (this);
-    m_saturationInput->setRange (-1, 1, .1/*step*/, true/*slider*/);
+    m_saturationInput = new kpDoubleNumInput (this);
+    m_saturationInput->setRange (-1, 1, 0.1/*step*/);
 
-    m_valueInput = new KDoubleNumInput (this);
-    m_valueInput->setRange (-1, 1, .1/*step*/, true/*slider*/);
+    m_valueInput = new kpDoubleNumInput (this);
+    m_valueInput->setRange (-1, 1, 0.1/*step*/);
 
     hueLabel->setBuddy (m_hueInput);
     saturationLabel->setBuddy (m_saturationInput);
@@ -74,36 +74,31 @@ kpEffectHSVWidget::kpEffectHSVWidget (bool actOnSelection, QWidget *parent)
     lay->setColumnStretch (1, 1);
 
 
-    connect (m_hueInput, SIGNAL (valueChanged(double)),
-             this, SIGNAL (settingsChangedDelayed()));
+    connect (m_hueInput, &kpDoubleNumInput::valueChanged,
+             this, &kpEffectHSVWidget::settingsChangedDelayed);
 
-    connect (m_saturationInput, SIGNAL (valueChanged(double)),
-             this, SIGNAL (settingsChangedDelayed()));
+    connect (m_saturationInput, &kpDoubleNumInput::valueChanged,
+             this, &kpEffectHSVWidget::settingsChangedDelayed);
 
-    connect (m_valueInput, SIGNAL (valueChanged(double)),
-             this, SIGNAL (settingsChangedDelayed()));
+    connect (m_valueInput, &kpDoubleNumInput::valueChanged,
+             this, &kpEffectHSVWidget::settingsChangedDelayed);
 }
 
-kpEffectHSVWidget::~kpEffectHSVWidget ()
-{
-}
+kpEffectHSVWidget::~kpEffectHSVWidget () = default;
 
 
 // public virtual [base kpEffectWidgetBase]
 QString kpEffectHSVWidget::caption () const
 {
     // TODO: Why doesn't this have a caption?  Ditto for the other effects.
-    return QString();
+    return {};
 }
 
 
 // public virtual [base kpEffectWidgetBase]
 bool kpEffectHSVWidget::isNoOp () const
 {
-    if (m_hueInput->value () == 0 && m_saturationInput->value () == 0 && m_valueInput->value () == 0)
-        return true;
-    else
-        return false;
+    return m_hueInput->value () == 0 && m_saturationInput->value () == 0 && m_valueInput->value () == 0;
 }
 
 // public virtual [base kpEffectWidgetBase]
