@@ -43,7 +43,7 @@ Q_OBJECT
 public:
     kpEffectInvertWidget (bool actOnSelection,
                           QWidget *parent);
-    virtual ~kpEffectInvertWidget ();
+    ~kpEffectInvertWidget () override;
 
 
     int channels () const;
@@ -53,13 +53,13 @@ public:
     // kpEffectWidgetBase interface
     //
 
-    QString caption () const Q_DECL_OVERRIDE;
+    QString caption () const override;
 
-    bool isNoOp () const Q_DECL_OVERRIDE;
-    kpImage applyEffect (const kpImage &image) Q_DECL_OVERRIDE;
+    bool isNoOp () const override;
+    kpImage applyEffect (const kpImage &image) override;
 
     kpEffectCommandBase *createCommand (
-        kpCommandEnvironment *cmdEnviron) const Q_DECL_OVERRIDE;
+        kpCommandEnvironment *cmdEnviron) const override;
 
 protected slots:
     void slotRGBCheckBoxToggled ();
