@@ -59,8 +59,9 @@ const int TableDefaultHeight = 52;
 
 static int TableNumColumns (const kpColorCollection &colorCol)
 {
-    if (colorCol.count () == 0)
+    if (colorCol.count () == 0) {
         return 0;
+    }
 
     return ::TableDefaultNumColumns;
 }
@@ -68,8 +69,9 @@ static int TableNumColumns (const kpColorCollection &colorCol)
 static int TableNumRows (const kpColorCollection &colorCol)
 {
     const int cols = ::TableNumColumns (colorCol);
-    if (cols == 0)
+    if (cols == 0) {
         return 0;
+    }
 
     return (colorCol.count () + (cols - 1)) / cols;
 }
@@ -84,10 +86,11 @@ static int TableCellWidth (const kpColorCollection &colorCol)
 
 static int TableCellHeight (const kpColorCollection &colorCol)
 {
-    if (::TableNumRows (colorCol) <= 2)
+    if (::TableNumRows (colorCol) <= 2) {
         return ::TableDefaultHeight / 2;
-    else
-        return ::TableDefaultHeight / 3;
+    }
+
+    return ::TableDefaultHeight / 3;
 }
 
 
@@ -98,7 +101,7 @@ static int TableCellHeight (const kpColorCollection &colorCol)
 
 struct kpColorCellsPrivate
 {
-    Qt::Orientation orientation;
+    Qt::Orientation orientation{};
 
     // REFACTOR: This is data duplication with kpColorCellsBase::color[].
     //           We've probably forgotten to synchronize them in some points.
@@ -121,9 +124,9 @@ struct kpColorCellsPrivate
     kpColorCollection colorCol;
 
     QUrl url;
-    bool isModified;
+    bool isModified{};
 
-    bool blockColorChangedSig;
+    bool blockColorChangedSig{};
 };
 
 //---------------------------------------------------------------------
@@ -175,13 +178,14 @@ kpColorCells::kpColorCells (QWidget *parent,
     // containing widgets to get too big.  Override it.
     setSizePolicy (QSizePolicy::Minimum, QSizePolicy::Minimum);
 
+    connect (this, &kpColorCells::colorSelectedWhitButton,
+             this, &kpColorCells::slotColorSelected);
 
-    connect (this, SIGNAL (colorSelected(int,QColor,Qt::MouseButton)),
-             SLOT (slotColorSelected(int,QColor,Qt::MouseButton)));
-    connect (this, SIGNAL (colorDoubleClicked(int,QColor)),
-             SLOT (slotColorDoubleClicked(int,QColor)));
-    connect (this, SIGNAL (colorChanged(int,QColor)),
-             SLOT (slotColorChanged(int,QColor)));
+    connect (this, &kpColorCells::colorDoubleClicked,
+             this, &kpColorCells::slotColorDoubleClicked);
+
+    connect (this, &kpColorCells::colorChanged,
+             this, &kpColorCells::slotColorChanged);
 
 
     setColorCollection (DefaultColorCollection ());
@@ -258,7 +262,7 @@ void kpColorCells::makeCellsMatchColorCollection ()
     else
     {
         c = ::TableNumRows (d->colorCol);
-        r = ::TableNumColumns (d->colorCol);;
+        r = ::TableNumColumns (d->colorCol);
     }
 
 #if DEBUG_KP_COLOR_CELLS
@@ -287,10 +291,12 @@ void kpColorCells::makeCellsMatchColorCollection ()
     //       cells don't have exactly the sizes requested here.  e.g. the
     //       top row of cells is 1 pixel shorter than the bottom row.  There
     //       are probably other glitches.
-    for (int y = 0; y < r; y++)
+    for (int y = 0; y < r; y++) {
         setRowHeight (y, CellHeight);
-    for (int x = 0; x < c; x++)
+    }
+    for (int x = 0; x < c; x++) {
         setColumnWidth (x, CellWidth);
+    }
 
 
     const bool oldBlockColorChangedSig = d->blockColorChangedSig;
@@ -317,7 +323,7 @@ void kpColorCells::makeCellsMatchColorCollection ()
         }
     #if DEBUG_KP_COLOR_CELLS && 0
         qCDebug(kpLogWidgets) << "\tSetting cell " << i << ": y=" << y << " x=" << x
-                  << " pos=" << pos << endl;
+                  << " pos=" << pos;
         qCDebug(kpLogWidgets) << "\t\tcolor=" << (int *) d->colorCol.color (i).rgba()
                   << "isValid=" << d->colorCol.color (i).isValid ();
     #endif
@@ -345,8 +351,9 @@ void kpColorCells::setModified (bool yes)
     qCDebug(kpLogWidgets) << "kpColorCells::setModified(" << yes << ")";
 #endif
 
-    if (yes == d->isModified)
+    if (yes == d->isModified) {
         return;
+    }
 
     d->isModified = yes;
 
@@ -388,8 +395,9 @@ const kpColorCollection *kpColorCells::colorCollection () const
 
 void kpColorCells::ensureHaveAtLeastOneRow ()
 {
-    if (d->colorCol.count () == 0)
+    if (d->colorCol.count () == 0) {
         d->colorCol.resize (::TableDefaultNumColumns);
+    }
 }
 
 //---------------------------------------------------------------------
@@ -527,8 +535,7 @@ void kpColorCells::slotColorSelected (int cell, const QColor &color,
 #if DEBUG_KP_COLOR_CELLS
     qCDebug(kpLogWidgets) << "kpColorCells::slotColorSelected(cell=" << cell
                << ") mouseButton = " << button
-               << " rgb=" << (int *) color.rgba()
-               << endl;
+               << " rgb=" << (int *) color.rgba();
 #else
     Q_UNUSED (cell);
 #endif
@@ -578,12 +585,14 @@ void kpColorCells::slotColorChanged (int cell, const QColor &color)
               << "d->colorCol.count()=" << d->colorCol.count ();
 #endif
 
-    if (d->blockColorChangedSig)
+    if (d->blockColorChangedSig) {
         return;
+    }
 
     // Cater for adding new colors to the end.
-    if (cell >= d->colorCol.count ())
+    if (cell >= d->colorCol.count ()) {
         d->colorCol.resize (cell + 1);
+    }
 
     // TODO: We lose color names on a color swap (during drag-and-drop).
     const int ret = d->colorCol.changeColor (cell, color,
